@@ -89,22 +89,22 @@ def get_data(obsid):
 	return run(cmd)
 
 def write_region(fname, ra, dec, src_flag, ra_back=-1, dec_back=-1, radius=120):
-	ff=open(fname,'w')
+	ff = open(fname, 'w')
 	ff.write("global color=green dashlist=8 3 width=1 font=\"helvetica 10 normal roman\" select=1 highlite=1 dash=0 fixed=0 edit=1 move=1 delete=1 include=1 source=1\nfk5\n")
 	if src_flag:
-		ff.write("circle(%.4f,%.4f,%.0f\")"%(ra,dec, radius))
+		ff.write("circle(%.4f,%.4f,%.0f\")" % (ra, dec, radius))
 	else:
 		#The default is just a guess
 		if ra_back == -1:
-			ra_deg=float(ra)-0.14
+			ra_deg = float(ra)-0.14
 		else:
 			ra_deg = float(ra_back)
 		if dec_back == -1:
-			dec_deg=float(dec)-0.08
+			dec_deg = float(dec)-0.08
 		else:
-			dec_deg=float(dec_back)
+			dec_deg = float(dec_back)
 
-		ff.write("circle(%.4f,%.4f,%.4f\")"%(ra_deg,dec_deg, float(radius)))
+		ff.write("circle(%.4f,%.4f,%.4f\")" % (ra_deg, dec_deg, float(radius)))
 	ff.close()
 
 
@@ -468,11 +468,8 @@ def process():
 	parser.add_argument("--write_baryevtfile", help="write barycentric corrected event files (in lightcurve)",
 						action='store_true')
 
-	# parser.add_argument("--pipeline_outdir",
-	# 					help='Location of pipeline products (_pipeline will be added) default is equal to outdir',
-	# 					type=str, default='outdir')
 	parser.add_argument("--repository", help='Location of the repository', type=str,
-						default='/gpfs0/ferrigno/NuSTAR/Repository')
+						default=os.environ['HOME']+'/NuSTAR/Repository')
 
 	if len(sys.argv) == 1:
 		parser.print_help()
@@ -489,8 +486,8 @@ def process():
 
 	PID = os.getpid()
 	logger.info("------------------------------------------------------------------------------------------------")
-	logger.info(" PID of the process ", PID)
-	logger.info(" kill -9 -%d  to kill current proc and children"%PID)
+	logger.info(" PID of the process %d" % PID)
+	logger.info(" kill -9 -%d  to kill current proc and children" % PID)
 	logger.info("------------------------------------------------------------------------------------------------")
 
 	obsid = args.OBSID[0]
@@ -532,6 +529,102 @@ def script_data():
 
 	process.get_data(obsid)
 
+def standard_processing_after_regions():
+	# Not a completely general tool, specific for a project
+	# Usable calling this file
+	help = sys.argv[0] + '\n'
+	help += '\n'
+	help += 'Process Nustar repository and extracts standard products for the HMXB project\n'
+
+	parser = argparse.ArgumentParser(description='Standard Process Nustar Data for the HMXB project',
+									 formatter_class=argparse.ArgumentDefaultsHelpFormatter)
+	parser.add_argument('mypath', metavar='mypath', type=str, nargs=1,
+						help='Path whenre you process data , e.g. Her_X1/10202002002 ')
+
+	parser.add_argument('--outdir', type=str, default='obs',
+						help='output folder base name (to be appended with _pipeline, _lc, or _spec')
+
+	parser.add_argument("--timebin", help="timebin for LC (s)", type=float, default=0.1)
+
+	parser.add_argument("--eMin", help="minimum energy (keV) for LC", type=float, default=3)
+	parser.add_argument("--eMed", help="medium energy (keV) for LC", type=float, default=7)
+	parser.add_argument("--eMax", help="maximum energy (keV) for LC", type=float, default=30)
+	parser.add_argument("--repository", help='Location of the repository', type=str,
+						default=os.environ['HOME']+'/NUSTAR/Repository')
+	parser.add_argument("--clean", help="Cleans products before extracting", action='store_true')
+
+	if len(sys.argv) == 1:
+		parser.print_help()
+		print(help)
+		sys.exit(1)
+
+	args = parser.parse_args()
+	my_path = args.mypath[0]
+	outdir_base = args.outdir
+
+	t_bin = args.timebin
+	e_min = args.eMin
+	e_med = args.eMed
+	e_max = args.eMax
+	repository = args.repository
+	clean = args.clean
+
+	print("Path is %s" % my_path)
+
+	try:
+		os.chdir(my_path)
+	except:
+		raise FileExistsError("The folder %s does not exist" % my_path)
+
+	import yaml
+
+	try:
+		with open('observation.yml', 'r') as outfile:
+			src_dict = yaml.load(outfile, Loader=yaml.FullLoader)
+	except:
+		raise FileExistsError("The file observation.yams does not exist in  %s" % my_path)
+
+	print(src_dict)
+
+	from nustarpipeline import process, utils
+
+	obsid = src_dict['OBSID']
+	ra_src = src_dict['RA']
+	dec_src = src_dict['DEC']
+
+	if ((not os.path.isfile(outdir_base + "_spec/sourceA.reg")) or \
+			(not os.path.isfile(outdir_base + "_spec/sourceB.reg")) or \
+			(not os.path.isfile(outdir_base + "_spec/backgroundA.reg")) or \
+			(not os.path.isfile(outdir_base + "_spec/backgroundB.reg"))):
+		raise FileExistsError(
+			'You need to have region files in %s_spec make them with the option region_flag' % outdir_base)
+
+	if clean:
+		extensions_spec = ['pha', 'pi', 'arf', 'rmf', 'gif']
+		cmd = 'rm -f'
+		for ee in extensions_spec:
+			cmd += ' %s_spec/*.%s' % (outdir_base, ee)
+		process.run(cmd)
+
+		extensions_lc = ['pha', 'evt', 'lc', 'pco', 'xco', 'reg', 'txt']
+		cmd = 'rm -f'
+		for ee in extensions_lc:
+			cmd += ' %s_lc/*.%s' % (outdir_base, ee)
+		process.run(cmd)
+
+	process.wrap_process(obsid, ra_src, dec_src, outdir_base,  spec_flag=True, repository_location=repository)
+
+	process.wrap_process(obsid, ra_src, dec_src, outdir_base, lc_flag=True, t_bin=t_bin, e_min=e_min, e_max=e_med,
+						 repository_location=repository)
+
+	process.wrap_process(obsid, ra_src, dec_src, outdir_base, lc_flag=True, t_bin=t_bin, e_min=e_med,
+						 e_max=e_max, write_baryevtfile_flag=True, filter_evt_flag=True,
+						 repository_location=repository)
+
+	os.chdir(outdir_base+'_spec/')
+	utils.make_basic_fit()
+	os.chdir('..')
+
 if __name__ == "__main__":
-	process()
+	standard_processing_after_regions()
 
