@@ -62,7 +62,7 @@ def get_obsids(src):
     return output
 
 def make_basic_fit():
-    ff = open('files.xcm', 'w')
+    ff = open('files-auto.xcm', 'w')
     ff.write('stati cstat\n')
     ff.write('data 1:1 FPMA_sr_rbn.pi\n')
     ff.write('data 2:2 FPMB_sr_rbn.pi\n')
@@ -74,18 +74,22 @@ def make_basic_fit():
     ff.write('freeze 2,3\nfit\n\n')
     ff.write('tha 2,3\nfit\n\n')
     ff.write('rm -f mod_base.xcm\nsave mod mod_base.xcm\n')
+    ff.write('setpl ene\ncpd basic-plot.gif/GIF\nplot ld del\n')
+    ff.write('quit\n\n')
+    ff.close()
+
+    ff = open('files-iterative.xcm', 'w')
+    ff.write('stati cstat\n')
+    ff.write('data 1:1 FPMA_sr_rbn.pi\n')
+    ff.write('data 2:2 FPMB_sr_rbn.pi\n')
+    ff.write('ignore bad\n')
+    ff.write('ignore *:**-3.0,70.0-**\n')
+    ff.write('@mod_base.xcm\n')
+    ff.write('query yes\n')
     ff.write('setpl ene\ncpd /XW\npl ld del\n')
     ff.close()
 
-    with open('files.xcm') as fi:
-        xspec_commands = fi.readlines()
-
-    with open('files-auto.xcm', 'w') as ff:
-        for ss in xspec_commands[:-2]:
-            ff.write(ss)
-        ff.write('cpd basic-plot.gif/GIF\nplot ld del\n')
-        ff.write('quit\n\n')
-    logger.debug(xspec_commands)
+    #logger.debug(xspec_commands)
     run('xspec - files-auto.xcm')
     from IPython.display import Image
     from IPython.display import display
@@ -155,13 +159,16 @@ def get_efold_frequency(nu_min, nu_max, min_en=3., max_en=20., n_bins=32, unit='
             if orbitfile is None:
                 ff.write(efold_cmd % (min_en, max_en, n_bins, nu_min, nu_max))
             else:
-                ff.write(efold_orbit_cmd % (min_en, max_en,orbitfile, n_bins, nu_min, nu_max))
+                if not os.path.isfile(orbitfile):
+                    raise FileExistsError('File %s does not exist' % orbitfile)
+
+                ff.write(efold_orbit_cmd % (min_en, max_en, orbitfile, n_bins, nu_min, nu_max))
 
         run()
 
     plot_periodogram()
 
-    x = np.loadtxt('ef_pipe_res.dat')
+    x = np.loadtxt('ef_pipe_res.dat', dtype=np.double)
 
     return x[2]
 
@@ -172,8 +179,8 @@ none
 n
 %d
 
-%f
-0
+%19.12e
+%19.12e
 0
 n
 %f
@@ -185,15 +192,44 @@ n
 1000000000
 '''
 
-def make_enphase(freq,  min_en=3., max_en=70., en_step=0.5, n_bins=32):
+enphase_cmd_orbit='''17
+list_evt.txt
+none
+%s
+y
+%s
+%d
+
+%19.12e
+%19.12e
+0
+n
+%f
+%f
+%f
+0
+0
+0
+1000000000
+'''
+
+def make_enphase(freq,  min_en=3., max_en=70., en_step=0.5, n_bins=32, orbitfile=None, nudot=0):
     for tt in ['source', 'background']:
         for unit in ['A', 'B']:
             with open('list_evt.txt', 'w') as ff:
                 ff.write('%s%s.evt' % (tt, unit))
 
-            with open('timing_cmd.txt', 'w') as ff:
-                ff.write(enphase_cmd % ('%s%s_ENPHASE.fits' % (tt, unit),
-                                 n_bins, freq, en_step, min_en, max_en) )
+            if orbitfile is None:
+                with open('timing_cmd.txt', 'w') as ff:
+                    ff.write(enphase_cmd % ('%s%s_ENPHASE.fits' % (tt, unit),
+                                     n_bins, freq, nudot, en_step, min_en, max_en) )
+            else:
+                if not os.path.isfile(orbitfile):
+                    raise FileExistsError('File %s does not exist' % orbitfile)
+
+                with open('timing_cmd.txt', 'w') as ff:
+                    ff.write(enphase_cmd_orbit % ('%s%s_ENPHASE.fits' % (tt, unit), orbitfile,
+                                     n_bins, freq, nudot, en_step, min_en, max_en) )
 
             run()
 
@@ -201,7 +237,7 @@ def read_one_matrix(kind, unit, background_difference_limit=5):
     import astropy.io.fits as pf
 
     if not (unit == 'A' or unit == 'B'):
-        raise  UserWarning('The unit must be A or B, you have %s ' % unit )
+        raise UserWarning('The unit must be A or B, you have %s ' % unit)
 
     if kind == 'E':
         fname_src = 'source%s_ENPHASE.fits' % unit
@@ -267,8 +303,8 @@ def get_ind_combine_engine(x1, x2):
     ind2 = []
     n_removed = 0
     for i in range(len(x1)):
+        not_found = True
         for j in range(max((i - n_removed), 0), len(x2)):
-            not_found = True
             if x1[i] == x2[j]:
                 ind1.append(i)
                 ind2.append(j)
@@ -298,8 +334,8 @@ none
 n
 %d
 
-%f
-0
+%19.12e
+%19.12e
 0
 n
 %f
@@ -309,19 +345,44 @@ n
 %f
 '''
 
-def make_tphase(freq,  min_en=3., max_en=70., t_step=1000, n_bins=32):
+tphase_cmd_orbit='''12
+list_evt.txt
+none
+%s
+y
+%s
+%d
+
+%19.12e
+%19.12e
+0
+n
+%f
+0
+0
+%f
+%f
+'''
+
+def make_tphase(freq,  min_en=3., max_en=70., t_step=1000, n_bins=32, orbitfile=None, nudot=0):
     for tt in ['source', 'background']:
         for unit in ['A', 'B']:
             with open('list_evt.txt', 'w') as ff:
                 ff.write('%s%s.evt' % (tt, unit))
 
             with open('timing_cmd.txt', 'w') as ff:
-                ff.write(tphase_cmd % ('%s%s_TPHASE.fits' % (tt, unit),
-                                 n_bins, freq, t_step, min_en, max_en) )
+                if orbitfile is None:
+                    ff.write(tphase_cmd % ('%s%s_TPHASE.fits' % (tt, unit),
+                                     n_bins, freq, nudot, t_step, min_en, max_en) )
+                else:
+                    if not os.path.isfile(orbitfile):
+                        raise FileExistsError('File %s does not exist' % orbitfile)
+                    ff.write(tphase_cmd_orbit % ('%s%s_TPHASE.fits' % (tt, unit), orbitfile,
+                                           n_bins, freq, nudot, t_step, min_en, max_en))
 
             run()
 
-def rebin_matrix(e_min, e_max, pp, dpp, min_s_n = 50):
+def rebin_matrix(e_min, e_max, pp, dpp, min_s_n = 50, only_pulsed=False):
 
     new_pulses = []
     dnew_pulses = []
@@ -329,7 +390,11 @@ def rebin_matrix(e_min, e_max, pp, dpp, min_s_n = 50):
     new_e_maxs = []
     i1 = 0
     while i1 < len(e_min) - 1:
-        p1 = pp[i1, :]
+        if only_pulsed:
+            p1 = pp[i1, :] - np.mean(pp[i1, :])
+        else:
+            p1 = pp[i1, :]
+
         dp1 = dpp[i1, :]
         i1_store = i1
         #print(i1)
@@ -442,7 +507,7 @@ def get_error_from_simul(counts, counts_err, method, n_simul=100, **kwargs):
 
     return np.std(simul_rms)
 
-def fft_pulsed_fraction(x, dx, level=0.1, n_harm_min=2, plot=False):
+def fft_pulsed_fraction(x, dx, level=0.1, n_harm_min=2, plot=False, verbose=True):
     '''
     Computes the pulsed fraction using an FFT. It stops as soon as the pulse is described at beter than level
     :param x:
@@ -465,10 +530,11 @@ def fft_pulsed_fraction(x, dx, level=0.1, n_harm_min=2, plot=False):
         y = np.real(ifft)
 
         chi2_val = np.sum(((x - y) / dx) ** 2)
-        dof = 1 + 2 * (n_harm - 1)
-        if chi2.cdf(chi2_val, dof) < level:
+        dof = max(1, n - (1 + 2 * (n_harm - 1)))
+        if chi2.sf(chi2_val, dof) > level:
             break
-
+    if verbose:
+        logger.info("Used %d harmonics for pulse description" % n_harm)
     a = np.absolute(fft) / n
     pulsed_frac = np.sqrt(np.sum(a[1:n_harm] ** 2) + np.sum(a[-n_harm + 1:] ** 2)) / a[0]
 
@@ -492,7 +558,7 @@ def pulse_fraction_from_data_min_max(x,dx):
     return pulsed_frac, dpulsed_frac
 import matplotlib.cm
 def plot_matrix_as_image(ee, pp, kind='E', normalize=True,outfile=None, cmap=matplotlib.cm.gist_earth,
-                         sliders=False, n_levels=30):
+                         sliders=False, n_levels=30, min_level=None, max_level=None, source_name=None):
     '''
 
     :param ee: y-scale (time or energy)
@@ -505,10 +571,16 @@ def plot_matrix_as_image(ee, pp, kind='E', normalize=True,outfile=None, cmap=mat
     ;param cmap the colormap of matplotlib, defaults to matplotlib.cm.gist_earth
     ;param sliders if True uses sliders
     ;param n_levels the number of linearly spaced contour levels
+    ;param min_level the minimum level for contours
+    ;param max_level the maximum level for contours
+    ;param source_name if not None, it is used as plot title
     :return:
     '''
 
+    import matplotlib.pyplot as plt
     from matplotlib.widgets import Slider
+    # from matplotlib.widgets import Button
+
     if pp.shape[0] != len(ee):
         raise ImportError('len(ee) [%d] != # rows pp [%d]' % (len(ee), pp.shape[0]))
     pp1 = pp.copy()
@@ -520,9 +592,14 @@ def plot_matrix_as_image(ee, pp, kind='E', normalize=True,outfile=None, cmap=mat
             pp1[i, :] = (x - m) / s
 
     phi = np.linspace(0, 1, pp.shape[1])
-    import matplotlib.pyplot as plt
     plt.figure()
-    levels = np.linspace(np.min(pp), np.max(pp), n_levels)
+    # if sliders:
+    #     plt.subplots_adjust(top=0.82)
+    if min_level is None:
+        min_level = np.min(pp1)
+    if max_level is None:
+        max_level = np.max(pp1)
+    levels = np.linspace(min_level, max_level, n_levels)
     cs = plt.contourf(phi, ee, pp1, cmap=cmap, levels=levels,
                            extend="both", zorder=0)
     cs.cmap.set_under('k')
@@ -538,6 +615,9 @@ def plot_matrix_as_image(ee, pp, kind='E', normalize=True,outfile=None, cmap=mat
     elif kind == 'NE':
         plt.yscale('log')
         plt.ylabel('$E/E_\\mathrm{Cyc}$')
+
+    if source_name is not None:
+        plt.title(source_name)
     if outfile is not None:
         plt.savefig(outfile)
 
@@ -545,10 +625,18 @@ def plot_matrix_as_image(ee, pp, kind='E', normalize=True,outfile=None, cmap=mat
         # Nice to have : slider
         cmin = plt.axes([0.05, 0.95, 0.3, 0.02])
         cmax = plt.axes([0.65, 0.95, 0.3, 0.02])
-        data_min = pp[np.isfinite(pp)].min()
-        data_max = pp[np.isfinite(pp)].max()
-        smin = Slider(cmin, 'Min', data_min, data_max, valinit=1., orientation='horizontal')
-        smax = Slider(cmax, 'Max', data_min, data_max, valinit=10., orientation='horizontal')
+
+        smin = Slider(cmin, 'Min', min_level, max_level, valinit=np.min(levels), orientation='horizontal')
+        smax = Slider(cmax, 'Max', min_level, max_level, valinit=np.max(levels), orientation='horizontal')
+        # areplot = plt.axes([0.4, 0.88, 0.1, 0.05])
+        # bnext = Button(areplot, 'Reset', color='0.55', hovercolor='0.9')
+        n_levels = 10
+
+        # def reset(x):
+        #     smin.reset()
+        #     smax.reset()
+        # cid = bnext.on_clicked(reset)
+
         def update(x):
             if smin.val < smax.val:
                 cs.set_clim(smin.val, smax.val)
@@ -556,6 +644,10 @@ def plot_matrix_as_image(ee, pp, kind='E', normalize=True,outfile=None, cmap=mat
         smin.on_changed(update)
         smax.on_changed(update)
 
+        return cs
+
+
+
 
 def plot_matrix_as_lines(t, pp, dpp, kind='T', normalize=False, offset=0):
     '''
@@ -588,6 +680,11 @@ def plot_matrix_as_lines(t, pp, dpp, kind='T', normalize=False, offset=0):
     plot_dpt = np.tile(dpt, 2)
 
     total_offset = 0
+    from matplotlib.colors import hsv_to_rgb
+    from cycler import cycler
+    colors = [hsv_to_rgb([(i * 0.618033988749895) % 1.0, 1, 1])
+              for i in range(pt.shape[0])]
+    plt.rc('axes', prop_cycle=(cycler('color', colors)))
     for i in range(pt.shape[0]):
 
         y = plot_pt[i, :]
@@ -596,12 +693,16 @@ def plot_matrix_as_lines(t, pp, dpp, kind='T', normalize=False, offset=0):
             # if np.sum(y) / np.sqrt(np.sum(dy ** 2)) > 10:
             label = "%.0f s" % ( t[i] - t[0])
             if kind == 'E':
-                label = "%.0f keV" % t[i]
-            plt.errorbar(phi, y+total_offset, xerr=0.5 / pt.shape[1], yerr=dy, linestyle='-', marker='.', label=label)
+                label = "%.1f keV" % t[i]
+            ebar = plt.errorbar(phi, y+total_offset, xerr=0.5 / pt.shape[1], yerr=dy, linestyle='-',
+                                marker='.', label=label)
+            plt.text(phi[int(plot_pt.shape[1]*0.75)], y[int(plot_pt.shape[1]*0.75)]+total_offset, label,
+                     color=ebar[0].get_color())
+            #print(int(pt.shape[1]/2), phi[int(pt.shape[1]/2)], y[int(pt.shape[1]/2)]+total_offset,)
             total_offset += offset
     plt.ylabel('Rate per bin')
     plt.xlabel('Phase')
-    plt.legend()
+    #plt.legend()
 
 def get_fourier_coeff(pulse):
     phi = np.linspace(0, 2 * np.pi, len(pulse))
@@ -634,6 +735,32 @@ def get_fourier_coeff_error( counts, counts_err, n_simul=100):
 
     return np.std(sim_phi0), np.std(sim_phi0_2,), np.std(sim_A), np.std(sim_A2)
 
+def get_cross_correlation(pp, plot=False):
+
+    correlation = []
+    lag = []
+    for i in range(pp.shape[0]):
+
+        x = (pp[i, :] - np.mean(pp[i, :])) / np.std(pp[i, :])
+        y = np.sum(pp[0:i, :], 0) + np.sum(pp[i + 1:, :], 0)
+        y = (y - np.mean(y)) / np.std(y)
+        corr = np.correlate(np.tile(x, 2), y) / len(x)
+        correlation.append(np.max(corr))
+        lag.append(np.argmax(corr))
+
+    if plot:
+        import matplotlib.pyplot as plt
+        plt.figure()
+        plt.subplot(1, 2, 1)
+        plt.plot(corr)
+        plt.subplot(1, 2, 2)
+        plt.plot(x)
+        plt.plot(y, linestyle='--')
+
+    lag = np.array(lag)
+    lag[lag > (pp.shape[1]/2)] -= pp.shape[1]
+    return lag, np.array(correlation)
+
 def get_target_coords_extern(input_name):
     from astroquery.simbad import Simbad
     from astropy import units as u
